# Changelog

## 0.12.0 (2024-12-17)

Full Changelog: [v0.11.1...v0.12.0](https://github.com/dodopayments/dodopayments-python/compare/v0.11.1...v0.12.0)

### Features

* **api:** api update ([#8](https://github.com/dodopayments/dodopayments-python/issues/8)) ([77cf406](https://github.com/dodopayments/dodopayments-python/commit/77cf406ce935a51c381e19a6a427749e585c4def))
* **api:** updated openapi methods ([#11](https://github.com/dodopayments/dodopayments-python/issues/11)) ([de9e970](https://github.com/dodopayments/dodopayments-python/commit/de9e970593dd95881a9dc2806e7384e10a4cddbe))


### Chores

* **internal:** codegen related update ([#10](https://github.com/dodopayments/dodopayments-python/issues/10)) ([043abd0](https://github.com/dodopayments/dodopayments-python/commit/043abd0050b67ea4fe271c79f546922740c46c0e))

## 0.11.1 (2024-12-16)

Full Changelog: [v0.11.0...v0.11.1](https://github.com/dodopayments/dodopayments-python/compare/v0.11.0...v0.11.1)

### Features

* **api:** manual updates ([#5](https://github.com/dodopayments/dodopayments-python/issues/5)) ([c9fc026](https://github.com/dodopayments/dodopayments-python/commit/c9fc026d3e229c37c7d8bfb87189f9841cf2ece7))

## 0.11.0 (2024-12-16)

Full Changelog: [v0.0.1-alpha.0...v0.11.0](https://github.com/dodopayments/dodopayments-python/compare/v0.0.1-alpha.0...v0.11.0)

### Features

* **api:** update via SDK Studio ([26a2d8b](https://github.com/dodopayments/dodopayments-python/commit/26a2d8b386155eda8e36ca7cd8c932997f76fa5c))
* **api:** update via SDK Studio ([9e9a8e7](https://github.com/dodopayments/dodopayments-python/commit/9e9a8e74538ba1de3cf3dbeeaeb0cbc9f3e7c43b))
* **api:** update via SDK Studio ([6f936f7](https://github.com/dodopayments/dodopayments-python/commit/6f936f74ec25259b59094dff239f7f64573e9ff3))
* **api:** update via SDK Studio ([bc0ceee](https://github.com/dodopayments/dodopayments-python/commit/bc0ceee97417a2838dc2027c5f3d6d47f8946e8f))
* **api:** update via SDK Studio ([9e3e121](https://github.com/dodopayments/dodopayments-python/commit/9e3e121d1e860ec91a9aa691e1f054edb2eb115c))
* **api:** update via SDK Studio ([fc0dbfe](https://github.com/dodopayments/dodopayments-python/commit/fc0dbfe7c4cc9d6199402bbb90f70d6e2ce8440d))
* **api:** update via SDK Studio ([39689b9](https://github.com/dodopayments/dodopayments-python/commit/39689b9b26cc01bb3b8890d7a7c7f3b0bf4445cd))
* **api:** update via SDK Studio ([dd36b5e](https://github.com/dodopayments/dodopayments-python/commit/dd36b5e5869f5f6ef5264ed20529a37ea4016fc0))


### Chores

* go live ([#1](https://github.com/dodopayments/dodopayments-python/issues/1)) ([6786737](https://github.com/dodopayments/dodopayments-python/commit/6786737914b7f2a36250ef8c2754d405b96a809d))
* **internal:** add support for TypeAliasType ([1d86b93](https://github.com/dodopayments/dodopayments-python/commit/1d86b9379e348777362a0e67334344e7a237032b))
* **internal:** bump pyright ([175e696](https://github.com/dodopayments/dodopayments-python/commit/175e6961135f0d4cddb5621b37744f60d30b19ce))
* **internal:** codegen related update ([cb7a979](https://github.com/dodopayments/dodopayments-python/commit/cb7a9791834d976f66e9bd6caa944d5a495917ee))
* **internal:** codegen related update ([19d85bf](https://github.com/dodopayments/dodopayments-python/commit/19d85bf829707326a0ea40a59d78ce72f101c153))
* **internal:** updated imports ([6894776](https://github.com/dodopayments/dodopayments-python/commit/6894776d2f1d7e546db913679379902a5742dd7f))
* update SDK settings ([#3](https://github.com/dodopayments/dodopayments-python/issues/3)) ([f0311ea](https://github.com/dodopayments/dodopayments-python/commit/f0311eaa1ba3ca4b892af4432345a852fc8215fe))
